@@ -17,12 +17,14 @@ from keypartx.basemodes.avn_base import nlp
 ## -- avnn edges-- ##
 def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False, emojis = True,check_spell = True):
     """
+    comments_en:  list of text 
     include_otherEdge: greedy edges of the unmatched adj, verb, noun 
     only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
     nounDEL : nouns to be removed 
     adjDEL : adjective to be removed 
     facility: additional noun for the missing in the include_otherEdge class, e.g. I recommend! So pretty! 
     faciNN: add facility noun to NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
+    emojis: if true, it will return a list of emojis in text, otherwise dropped 
     """
     time_start = time.time()
     all_adjV2N_edges = []
@@ -93,8 +95,11 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
 
 
 ## -- avn network -- ## 
-def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_add ="avnn.html",height='600px', width='100%',bgcolor='white',font_color="black", directed = True, notebook =True):
-
+def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_add ="avnn.html",height='600px', width='100%',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
+    """ all_edges1: weighted edges 
+        core_k: if node degree is less than k then edge droped
+        cdn=['remote','local'] more in pyvis 
+    """
     # get Networkx 
     #import math
     Gd = nx.DiGraph() 
@@ -105,7 +110,7 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
 
 
     # pyvis network plot 
-    nt=Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook )
+    nt=Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook,cdn_resources=cdn )
     nt.set_edge_smooth('cubicBezier')
     error_noeds =[]
     nodes = []
@@ -144,10 +149,10 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
     weights = []
     all_edges =[]              # get final all_edges after errors 
     for edge in all_edges1:
-      if any(ern in edge for ern in error_noeds):
+      if any(ern in edge for ern in error_noeds): 
         print(edge,':error edge removed')
 
-      elif all([dict(Gd.degree)[node]>=core_K for node in edge[:2]]):                   
+      elif all([dict(Gd.degree)[node]>=core_K for node in edge[:2]]):         # core_k if node degree is less than k then edge droped         
         elabel = str(edge[2])
         value = int(edge[2])
         weights.append(edge[2])
@@ -172,13 +177,15 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
 
 
 ## -- avn network colored by community 
-def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_add ="network_community.html",height='600px', width='100%',heading='Community Network'):
+def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_add ="network_community.html",height='600px', width='100%',heading='Community Network', directed = True, notebook =True,cdn='remote'):
     #import matplotlib
-
+    """ 
+        cdn=['remote','local'] more in pyvis 
+    """
     #from itertools import cycle, islice
     colorList1  = list(islice(cycle(colorList_rgba1),len(partition)))
 
-    ntc=Network(height=height, width=width,heading=heading,bgcolor='white',font_color="black", directed = True, notebook =True)
+    ntc=Network(height=height, width=width,heading=heading,bgcolor='white',font_color="black", directed = directed, notebook =notebook ,cdn=cdn)
     ntc.set_edge_smooth('cubicBezier')
     error_noeds =[]
     for com, color in zip(partition, colorList1):
@@ -229,9 +236,11 @@ def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_
 
 ## --plot color by nouns in AVNN community --#
 
-def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_add = 'community_NNColors.html', height='600px', width='100%',heading='Community_NNColors',bgcolor='white',font_color="black", directed = True, notebook =True):
+def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_add = 'community_NNColors.html', height='600px', width='100%',heading='Community_NNColors',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
     #import matplotlib,itertools
-
+    """ 
+        cdn=['remote','local'] more in pyvis 
+    """
     partition_all_names = [] 
     for index in partition:
         partition_all_names.append([iGd.vs[index]['name'] for index in index])
@@ -269,7 +278,7 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
     ## nn com 
     colorList1  = list(islice(cycle(colorList_rgba1),len(nodes_NN_index )))
 
-    ntc2 =Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed =directed, notebook =notebook)
+    ntc2 =Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed =directed, notebook =notebook,cdn=cdn)
     ntc2.set_edge_smooth('cubicBezier')
     com_nn_a = 0
     com_nn_aa = []
@@ -351,7 +360,11 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
 
 
 ## -single community with gray connection -## 
-def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_folder='gray_units/',height='600px', width='100%',heading='Gray Unit Community Network',bgcolor='white',font_color="black", directed = True, notebook =True):
+def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_folder='gray_units/',height='600px', width='100%',heading='Gray Unit Community Network',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
+    """ 
+        cdn=['remote','local'] more in pyvis 
+    """    
+    
     if comLen == False:
         com_len = len(set(nnColor_df.community_nn.to_list()))
     else:
@@ -381,7 +394,7 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
       #print(len(set(comEdges)))
       comEdges = sorted(set(comEdges))
 
-      ntc3=Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook)
+      ntc3=Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook,cdn=cdn)
       ntc3.set_edge_smooth('cubicBezier')
 
 
@@ -481,5 +494,5 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
     colorGrayDF = pd.DataFrame({'commus': commus,'colorEdges':colorEdges,'colorNodes':colorNodes,'grayEdges':grayEdges,'grayNodes':grayNodes})
     return colorGrayDF
   
-  
-comments_en =["Once again a memorable visit to Arctic Light. Hearty staff, tasty breakfast (special mention of crispy waffles and rice porridge!), Clean and well-equipped room. Good bed. High quality and tastefully decorated. ❤️ We recommend and book your next stay at the Arctic Light Hotel. 😊"]
+
+#comments_en =["Once again a memorable visit to Arctic Light. Hearty staff, tasty breakfast (special mention of crispy waffles and rice porridge!), Clean and well-equipped room. Good bed. High quality and tastefully decorated. ❤️ We recommend and book your next stay at the Arctic Light Hotel. 😊"]
