@@ -474,4 +474,103 @@ def emo(text):
       words.append(x2)
   new_text = " ".join(words)
   return new_text, emojis
-  
\ No newline at end of file
+  
+def vaderAV():
+  vader_text = pd.read_csv("https://raw.githubusercontent.com/pengKiina/KeypartX/main/vader_lexicon.csv")
+  #vader_text
+  words= vader_text.token.to_list()
+  vader_adjs =[]
+  vader_verbs = []
+  for word in words:
+    doc = nlp(word)
+    if doc[0].pos_ == "ADJ" and len(doc[0].lemma_)>2 :
+      ns = doc[0].lemma_
+      if "sse" == ns[-3:] or "ness" == ns[-4:] :
+        #print('adj',ns)
+        pass
+      else:
+        vader_adjs.append(ns)
+    elif doc[0].pos_ == "VERB" and len(doc[0].lemma_)>2:
+      ns = doc[0].lemma_
+      if "sse" == ns[-3:] or "ness" == ns[-4:] :
+        #print('verb', ns)
+        pass
+      else:
+        vader_verbs.append(ns)
+  adjs_set = set(vader_adjs)
+  #print(len(vader_adjs))
+  #print(len(adjs_set))
+  verbs_set = set(vader_verbs)
+  verbs_set = (set([verbs_set]) - set(['lovelie']))
+  #print(len(vader_verbs))
+  #print(len(verbs_set))
+  
+  vader_df = pd.DataFrame.from_dict({'vader_adjs':adjs_set,'vader_verbs':verbs_set},orient = 'index')
+  vader_df = vader_df.transpose()
+  return vader_df, adjs_set, verbs_set 
+
+
+# new for back and again
+
+def abverb(abtext):
+    """
+    again, back # visit, come, go, travel, be 
+    """
+    #abtext = "We notlove2vvv it again to Finland, I came back to Finland"
+    #abtext ="I come to Finland again"
+    matcher1 = Matcher(nlp.vocab)
+    pattern1 = [{"POS": 'VERB'}, {'IS_ASCII': True, 'OP': '{0,3}'},{"LOWER": 'back'}] #"OP":"+" 1 or more * 0 or more  # ADP: 'from' ,'to'
+    matcher1.add('verb + back', [pattern1])
+    pattern2 = [{"POS": 'VERB'}, {'IS_ASCII': True, 'OP': '{0,3}'},{"LOWER": 'again'}]#"OP":"+" 1 or more * 0 or more
+    matcher1.add('verb + again', [pattern2])
+
+    #textneg = "I do not like you never know it be not really pretty, it means no money no girl"
+    doc = nlp(abtext)
+
+    matches = matcher1(doc)
+    spans =[]
+    for match_id, start, end in matches:
+      # Get the matched span by slicing the Doc
+      span = doc[start:end]
+      #print(span.text)
+      if len(span.text.split())>1: #not,not like
+        spans.append(span)
+
+    ab_doc = spacy.util.filter_spans(spans) # only get the longest span
+
+    if len(ab_doc)>0:
+        ab_verbs = []
+        for abd in ab_doc:
+
+            abV =""
+            abV2=""
+            ab =""
+            for token in abd:
+                #print(token)
+                if token.pos_ == "VERB":
+                    abv = token.text
+                    abv2 = token.lemma_
+                    abV = abv.replace('2vvv','')
+                    abV2= abv2.replace('2vvv','')
+                   # print('abV',abV)
+                else:
+                    if token.text == "back":
+                        ab1 = token.text
+                        ab = ab1
+                    elif token.text == "again":
+                        ab1 =  token.text
+                        ab = ab1
+            #print(abV, abV2,ab)
+            if len(abV)>1:
+                #print(abd)
+                abd1 = abd.text.replace('2vvv',"")
+                #print(abd1)
+                ab_verb = abV2 +ab +'2vvv'
+                mapverb(ab_verb)  
+                abd2 =  re.sub(r'\b' +abV + r'\b',ab_verb, abd1)  # replace whole word 
+                #print(abd2)
+                abtext = abtext.replace(abd.text,abd2)
+                ab_verbs.append(ab_verb)
+        return abtext, ab_verbs 
+    else:
+        return abtext, []
\ No newline at end of file
