@@ -50,6 +50,8 @@ def k_edges(all_edges,weight_k =1):
   return all_edges_k
 
 def wedge_type(all_adjV2N_edges_w=[],allNNEdges_dir_w=[],nn_edges = True, aVn_edges = True,weight_k =1):
+    """ weight_k: drop all edges if weight less than k 
+    """
     include_nn_not =""
     all_edges1 = []
     if nn_edges == True and aVn_edges == True:
@@ -169,6 +171,9 @@ class unit2sent:
   ## 2. avn order by degree
 
   def avn2coren(self,c_noun,c_nounD=False,vdR = .1, adR =.1,ndR =.1):
+    """ 
+    verb, adjective and noun edges to core_noun in list of list 
+    """
     commu1_edges = self.commu_edges
     avns =[]
     avnWs = []
