@@ -17,7 +17,9 @@ import networkx as nx
 ## negative, conative verbs, non opinion adjective, arcticle, ordinal words
 
 
-opi_verbs = ['enjoy','love','like','adore','avoid','revisit','desire','dislike','hate','wish','hope','appreciate','value','recommend','unrecommend','astonish','impress','please','satisfy','unsatisfy','surprise','mean','mind']
+opi_verbs = ['enjoy','love','like','adore','avoid','revisit','desire','dislike','hate','wish','hope','appreciate','value','recommend','unrecommend','astonish','impress','please','satisfy','unsatisfy','surprise','mean','mind','overjoy', 'despair', 'disgust', 'attract', 'encourage', 'favour','favor', 'forget', 'remember','disappoint', 'discourage','fascinate',
+            'dissatisfy', 'disinterest', 'interest', 'complain', 'compliment', 'suffer' , 'trust', 'distrust' 'praise','content','miss']
+
 neg_words = ['hardly', 'scarcely','barely','no','not','none','neither','nor','never']
 #keep_words2 = keep_words +opi_verbs + neg_words
 #textneg = "I do not like you never know it be not really pretty, it means no money no girl, I hardly learn in the never nice school"
@@ -54,7 +56,7 @@ def negADJ(neg_words,adjDEL):
 
 
 
-def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,facility = False,faciNN = False, emojis = True, check_spell = True):
+def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,facility = False,faciNN = False, emojis = True, check_spell = True,back_again = True):
   """
   include_otherEdge: greedy edges of the unmatched adj, verb, noun 
   only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
@@ -219,6 +221,8 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
 
   mapadj(" ".join(negadj1 +['ok','pengy']))# ok INTJ , 
   mapverb(" ".join(negverb1))
+  
+  
 
   text3 = text2
   for old, new in zip(negadj0+negverb0,negadj1+negverb1):
@@ -227,8 +231,13 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   if verbose_text:
     print('text3(update negadj,negaverb): ', text3)
 
+  ## ---- back , again verb ---
+  if back_again:
+    text3,_ = abverb(text3)
 
-  #5. ecept compounds, other normal words into ADJ, VERB, NOUN 
+
+
+  #5. except compounds, other normal words into ADJ, VERB, NOUN 
 
   all_new_comps = quote1 + hyphen1 +entity1 + ncomp1 +negadj1 +negverb1
   #print('all_new_comps:',all_new_comps)
@@ -488,7 +497,7 @@ def targList(mylist):
 
 #from autocorrect import Speller
 #from collections import defaultdict
-def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,opi_verbs = opi_verbs ,neg_words =neg_words,adjDEL = adjDEL,nounDEL = nounDEL,only_opiAV = True,nncompound = True, emojis = True,check_spell = True):
+def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,opi_verbs = opi_verbs ,neg_words =neg_words,adjDEL = adjDEL,nounDEL = nounDEL,only_opiAV = True,nncompound = True, emojis = True,check_spell = True,back_again = True):
   non_opi_adjs = negADJ(neg_words,adjDEL)
   # 1. check spelling 
 
@@ -647,6 +656,10 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
   if verbose_text:
     print('text3(update negadj,negaverb): ', text3)
 
+ 
+  ## ---- back , again verb ---
+  if back_again:
+    text3,_ = abverb(text3)
 
   #5. ecept compounds, other normal words into ADJ, VERB, NOUN 
 
@@ -944,4 +957,6 @@ def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size =
   else:
     plt.savefig('nlp_target.png') 
   plt.show()
-  return type1s
\ No newline at end of file
+  return type1s
+
+
